/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.bank.util;

import java.util.Vector;

import javax.swing.JOptionPane;
import javax.swing.UIManager;

import org.ow2.wildcat.examples.bank.Customer;

/**
 * Bank GUI class used to perform transaction on customers accounts
 * @author Mahmoud Ben Hassine
 * 
 */
public class BankGUI extends javax.swing.JFrame {

	private static final long serialVersionUID = 8876826709128453504L;
	
    public BankGUI(String title) {
    	try {
    	      UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
    	    } catch(Exception e) {
    	      System.out.println("Error setting native LAF: " + e);
    	    }
    	setTitle(title);
        initComponents();
    }

    private void initComponents() {
    	
    	/*
    	 * get customers from the database
    	 */
        Vector<Customer> customers = BankDataBase.getInstance().getCustomers();
        
        customersScrollPane = new javax.swing.JScrollPane();
        customersList = new javax.swing.JList(customers);
        detailsLayeredPane = new javax.swing.JLayeredPane();
        identifierLabel = new javax.swing.JLabel();
        firstNameLabel = new javax.swing.JLabel();
        lastNameLabel = new javax.swing.JLabel();
        balanceLabel = new javax.swing.JLabel();
        transactionLayeredPane = new javax.swing.JLayeredPane();
        customerLabel = new javax.swing.JLabel();
        operationLabel = new javax.swing.JLabel();
        operationTextField = new javax.swing.JTextField();
        depositButton = new javax.swing.JButton();
        withdrawButton = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setName("Form");
        setResizable(false);

        customersScrollPane.setName("customersScrollPane");

        customersList.setBorder(javax.swing.BorderFactory.createTitledBorder("Customers")); 
        customersList.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        customersList.setName("customersList");
        customersList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                customersListValueChanged(evt);
            }
        });
        customersScrollPane.setViewportView(customersList);

        detailsLayeredPane.setBorder(javax.swing.BorderFactory.createTitledBorder("Details")); 
        detailsLayeredPane.setName("detailsLayeredPane");

        identifierLabel.setText("Identifier : "); 
        identifierLabel.setName("IdentifierLabel"); 
        identifierLabel.setBounds(10, 30, 190, 17);
        detailsLayeredPane.add(identifierLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        firstNameLabel.setText("First name : "); 
        firstNameLabel.setName("firstNameLabel"); 
        firstNameLabel.setBounds(10, 60, 190, 17);
        detailsLayeredPane.add(firstNameLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        lastNameLabel.setText("Last name : "); 
        lastNameLabel.setName("lastNameLabel"); 
        lastNameLabel.setBounds(10, 90, 190, 17);
        detailsLayeredPane.add(lastNameLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        balanceLabel.setText("Balance : "); 
        balanceLabel.setName("balanceLabel");
        balanceLabel.setBounds(10, 120, 190, 17);
        detailsLayeredPane.add(balanceLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        transactionLayeredPane.setBorder(javax.swing.BorderFactory.createTitledBorder("Transaction")); 
        transactionLayeredPane.setName("transactionLayeredPane"); 

        customerLabel.setText("Customer : "); 
        customerLabel.setName("customerLabel"); 
        customerLabel.setBounds(20, 30, 390, 17);
        transactionLayeredPane.add(customerLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        operationLabel.setText("Operation : "); 
        operationLabel.setName("newBalanceLabel"); 
        operationLabel.setBounds(20, 60, 90, 30);
        transactionLayeredPane.add(operationLabel, javax.swing.JLayeredPane.DEFAULT_LAYER);

        operationTextField.setText(""); 
        operationTextField.setName("newBalanceTextField");
        operationTextField.setBounds(120, 60, 140, 30);
        transactionLayeredPane.add(operationTextField, javax.swing.JLayeredPane.DEFAULT_LAYER);

        depositButton.setText("deposit"); 
        depositButton.setName("depositButton"); 
        depositButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
            	performTransaction(evt);
            }
        });
        depositButton.setBounds(340, 60, 70, 29);
        transactionLayeredPane.add(depositButton, javax.swing.JLayeredPane.DEFAULT_LAYER);

        withdrawButton.setText("withdraw");
        withdrawButton.setName("withdrawButton");
        withdrawButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
            	performTransaction(evt);
            }
        });
        withdrawButton.setBounds(270, 60, 67, 29);
        transactionLayeredPane.add(withdrawButton, javax.swing.JLayeredPane.DEFAULT_LAYER);
        
        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(transactionLayeredPane, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 428, Short.MAX_VALUE)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                        .addComponent(customersScrollPane, javax.swing.GroupLayout.PREFERRED_SIZE, 212, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(detailsLayeredPane, javax.swing.GroupLayout.DEFAULT_SIZE, 210, Short.MAX_VALUE)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(customersScrollPane)
                    .addComponent(detailsLayeredPane, javax.swing.GroupLayout.DEFAULT_SIZE, 155, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(transactionLayeredPane, javax.swing.GroupLayout.DEFAULT_SIZE, 109, Short.MAX_VALUE)
                .addContainerGap())
        );

        pack();
    }
    
    /*
     * perform a transaction
     */
    private void performTransaction(java.awt.event.ActionEvent evt){
    
    	String operation = evt.getActionCommand();
		Customer selectedCustomer = (Customer)customersList.getSelectedValue();
    	
    	double value ;
    	try {
    		value = Double.parseDouble(operationTextField.getText());
			if (operation.equals("withdraw"))
				selectedCustomer.getAccount().withdraw(value);
			else if (operation.equals("deposit"))
				selectedCustomer.getAccount().deposit(value);
			
			JOptionPane.showMessageDialog(this, "Transaction successfully performed", "Information", JOptionPane.INFORMATION_MESSAGE);
			balanceLabel.setText("Balance : " + selectedCustomer.getAccount().getBalance());
			
		}catch (NumberFormatException e) {
			JOptionPane.showMessageDialog(this, "Invalid numeric input : " + operationTextField.getText(), "Invalid input", JOptionPane.ERROR_MESSAGE);
		}catch (InsufficientAmountException e) {
			JOptionPane.showMessageDialog(this, e.getMessage(), "Insufficient balance", JOptionPane.ERROR_MESSAGE);
		}catch (IllegalArgumentException e){
			JOptionPane.showMessageDialog(this, e.getMessage(), "Illegal input", JOptionPane.ERROR_MESSAGE);
		}finally{
			operationTextField.setText("");
		}
    }
    
    /*
     * update GUI when a customer is selected in the customers list
     */
    private void customersListValueChanged(javax.swing.event.ListSelectionEvent evt) {	
			Customer selectedCustomer = (Customer)customersList.getSelectedValue();
			identifierLabel.setText("Identifier : " + selectedCustomer.getId());
			firstNameLabel.setText("First name : " + selectedCustomer.getFirstName());
			lastNameLabel.setText("Last name : " + selectedCustomer.getLastName());
			balanceLabel.setText("Balance : " + selectedCustomer.getAccount().getBalance());
			customerLabel.setText("Customer : " + selectedCustomer.getFullName());
    }

    private javax.swing.JLabel balanceLabel;
    private javax.swing.JButton depositButton;
    private javax.swing.JButton withdrawButton;
    private javax.swing.JLabel customerLabel;
    private javax.swing.JList customersList;
    private javax.swing.JLayeredPane detailsLayeredPane;
    private javax.swing.JLabel firstNameLabel;
    private javax.swing.JLabel identifierLabel;
    private javax.swing.JScrollPane customersScrollPane;
    private javax.swing.JLabel lastNameLabel;
    private javax.swing.JLabel operationLabel;
    private javax.swing.JTextField operationTextField;
    private javax.swing.JLayeredPane transactionLayeredPane;
    
}
