/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.bank.util;

import java.util.Date;

import org.ow2.wildcat.examples.bank.Account;


/**
 * Class encapsulating a bank account transaction details
 * @author Mahmoud Ben Hassine
 * 
 */
public class TxDetails {

	private Account account;
	private double oldBalance;
	private double newBalance;
	private Date date;
	
	public TxDetails() {
		
	}

	public TxDetails(Account account, double oldBalance, double newBalance, Date date) {
		this.account = account;
		this.oldBalance = oldBalance;
		this.newBalance = newBalance;
		this.date = date;
	}

	public Account getAccount() {
		return account;
	}

	public void setAccount(Account account) {
		this.account = account;
	}

	public double getOldBalance() {
		return oldBalance;
	}

	public void setOldBalance(double oldBalance) {
		this.oldBalance = oldBalance;
	}

	public double getNewBalance() {
		return newBalance;
	}

	public void setNewBalance(double newBalance) {
		this.newBalance = newBalance;
	}

	public Date getDate() {
		return date;
	}

	public void setTrDate(Date date) {
		this.date = date;
	}
	
	public Operation getOperation(){
		return ( newBalance < oldBalance )? Operation.WITHDRAW:Operation.DEPOSIT;
	}
	
	public double getAmount(){
		return Math.abs(newBalance - oldBalance);
	}
	
	public String toString(){
		return  " \nTransaction :" +
				" \n\t date = " + date.toString() +
				" \n\t account " + account.toString() + 
				" ; customer =  " + account.getOwner().toString() + 
				" \n\t old balance = " + oldBalance + 
				" ; new balance = " + newBalance + 
				" \n\t operation = " + getOperation() +
				" ; amount = " + getAmount();
	}
	
	/**
	 * Enumeration for possible operations to be performed on a bank account
	 * @author Mahmoud Ben Hassine
	 *
	 */
	private enum Operation { DEPOSIT , WITHDRAW }
	
}
