/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.sca.intent;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;

import com.espertech.esper.client.UpdateListener;
import com.espertech.esper.client.EventBean;

import org.ow2.wildcat.sca.intent.MonitoringData;

/**
 * A class holding wildcat context
 * 
 * @version 1.0
 * @author Mahmoud Ben Hassine
 * 
 */
public class WildcatContext{
	
	private static WildcatContext singleton;
	
	public static synchronized WildcatContext getInstance(){
		if (singleton == null)
			singleton = new WildcatContext();
		return singleton;
	}
	
	private Context ctx;
	
	private WildcatContext(){
		
		/*
		 * create wildcat context
		 */
		ctx = ContextFactory.getDefaultFactory().createContext();
		
		try {
			
			/*
			 * create simple hierarchy
			 */
			ctx.createAttribute("self://serviceEvent#eventData", new MonitoringData());
			
			/*
			 * create listener to notify attribute events
			 */
			UpdateListener ul = new UpdateListener() {
				public void update(EventBean[] newEvents, EventBean[] oldEvents) {
					MonitoringData md = (MonitoringData) newEvents[0].get("value");
					System.err.println(md);
				}
			};
			
			/*
			 * listen to all attribute events
			 */
			String query = "select * from WAttributeEvent";
			
			/*
			 * register the listener to the query
			 */
			ctx.registerListeners(query, ul);
			
		} catch (ContextException e) {
			e.printStackTrace();
		}
	}

	public void notify(MonitoringData md) throws ContextException {
		ctx.setValue("self://serviceEvent#eventData", md);		
	}
	
}
