/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2009 Bull S.A.S.
 * Copyright (C) 2009 EMN
 * Copyright (C) 2009 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 */
package org.ow2.wildcat;


/**
 * Define an action to be executed when an event is triggered
 * 
 * @author Mahmoud Ben Hassine
 *
 */
public abstract class WAction {

	/**
	 * The action name
	 */
	protected String name;
	
	/**
	 * The action description
	 */
	protected String description;
	
	/**
	 * The listener to be associated with the action
	 */
	private WUpdateListener listener;
	
	
	public WAction(){
		
	}

	public WAction(String name, String description) {
		this.name = name;
		this.description = description;
	}
	
	/**
	 * Getter for the action name
	 * 
	 * @return the action name
	 */
	public String getName(){
		return name;
	}

	/**
	 * Getter for the short description of the action
	 * 
	 * @return a short description of the action
	 */
	public String getDescription(){
		return description;
	}
	
	/**
	 * Setter for the action name
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * Setter for the short description of the action
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	
	/**
	 * Getter for the listener
	 */
	public WUpdateListener getListener(){
		return listener;
	}
	
	/**
	 * Setter for the listener
	 */
	public void setListener(WUpdateListener ul){
		listener = ul;
	}
	
	/**
	 * Executed when the associated event is triggered
	 */
	public abstract void onEvent();

	}
