/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: ContextOperation.java 350 2008-11-10 09:41:14Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.remote.dispatcher.jms;

import java.io.Serializable;

/**
 * Wrapper for a remote call.
 */
public class ContextOperation implements Serializable {

    private static final long serialVersionUID = 2862937495987429123L;

    private String target;

    private OperationType op;

    private Object[] args;

    /**
     * Constructor
     *
     * @param target
     *            name of the Remote Context on which to perform the operation
     * @param op
     *            the type of operation
     * @param args
     *            arguments of the remote call
     */
    public ContextOperation(final String target, final OperationType op, final Object... args) {
        this.target = target;
        this.op = op;
        this.args = args;
    }

    /**
     * A unique ID used to match reply with pending remote calls
     */
    private long id;

    /**
     * Getter
     *
     * @return a unique ID
     */
    public long getId() {
        return id;
    }

    /**
     * Setter
     *
     * @param id
     *            the unique ID
     */
    public void setId(final long id) {
        this.id = id;
    }

    /**
     * Getter
     *
     * @return name of the Remote Context on which to perform the call
     */
    public String getTarget() {
        return this.target;
    }

    /**
     * Getter
     *
     * @return arguments of the operation
     */
    public Object[] getArgs() {
        return this.args;
    }

    /**
     * Getter
     *
     * @return operation type
     */
    public OperationType getOp() {
        return this.op;
    }

    private String returnQueue;

    /**
     * Getter
     *
     * @return the name of the JMS queue on which to reply
     */
    public String getReturnQueue() {
        return returnQueue;
    }

    /**
     * Setter
     *
     * @param returnQueue
     *            the name of the JMS queue on which to reply
     */
    public void setReturnQueue(final String returnQueue) {
        this.returnQueue = returnQueue;
    }

    /*
     * (non-Javadoc)
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        String r = "RemoteCall (target: " + target + ", op " + this.op
        + ", args: ";
        if (this.args != null) {
            for (Object a : args) {
                r += a.toString() + ", ";
            }
        }
        r += " id: " + this.id + ", rq: " + this.returnQueue + ")";
        return r;
    }
}
