/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: RMIRemoteContext.java 420 2009-06-07 09:15:52Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.remote.dispatcher.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import javax.jms.ConnectionFactory;
import javax.jms.Topic;

import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.remote.RemoteContext;


/**
 * Define a way to retrieve the topic and topic connection factory created by this context.
 * @author Loris Bouzonnet
 */
public interface RMIRemoteContext extends Remote, RemoteContext {

    /**
     * @return the topic used by this context to emit its events
     * @throws RemoteException if the connection failed
     * @throws ContextException if the topic cannot be retrieved
     */
    Topic getTopicToSpy() throws RemoteException, ContextException;

    /**
     * @return the topic connection factory to create a listener of this context
     * @throws RemoteException if the connection failed
     * @throws ContextException if the topic connection factory cannot be retrieved
     */
    ConnectionFactory getTopicConnectionFactoryToSpy() throws RemoteException, ContextException;

}
