/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: JMSProvider.java 420 2009-06-07 09:15:52Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.remote.provider;

import javax.jms.ConnectionFactory;
import javax.jms.Queue;
import javax.jms.Topic;

import org.ow2.wildcat.ContextFactory;

/**
 * Interface to define different manners of getting a JMS Provider.
 * @author Loris Bouzonnet
 */
public interface JMSProvider {

    /**
     * Initialize a JMS provider with the given properties.
     * @param contextFactory a context factory
     * @throws JMSProviderException if the initialization failed
     */
    void init(ContextFactory contextFactory) throws JMSProviderException;

    /**
     * @return a topic connection factory
     * @throws JMSProviderException if a topic connection factory cannot be retrieved
     */
    ConnectionFactory getTopicConnectionFactory() throws JMSProviderException;

    /**
     * @return a queue connection factory
     * @throws JMSProviderException if a queue connection factory cannot be retrieved
     */
    ConnectionFactory getQueueConnectionFactory() throws JMSProviderException;

    /**
     * @param topicName a topic name
     * @return a topic with the given name
     * @throws JMSProviderException if a topic with the given name cannot be retrieved
     */
    Topic getTopic(String topicName) throws JMSProviderException;

    /**
     * @param queueName a queue name
     * @return a queue with the given name
     * @throws JMSProviderException if a queue with the given name cannot be retrieved
     */
    Queue getQueue(String queueName) throws JMSProviderException;

    void deleteTopic(String topicName) throws JMSProviderException;

    void deleteQueue(String queueName) throws JMSProviderException;

    /**
     * Destroy the JMS provider.
     */
    void destroy() throws JMSProviderException;

}
