/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: JORAMServer.java 420 2009-06-07 09:15:52Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.remote.provider.joram;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

import javax.jms.ConnectionFactory;
import javax.naming.Context;
import javax.naming.InitialContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.objectweb.joram.client.jms.admin.AdminModule;
import org.objectweb.joram.client.jms.admin.User;
import org.objectweb.joram.client.jms.tcp.TcpConnectionFactory;
import org.ow2.wildcat.ContextFactory;

import fr.dyade.aaa.agent.AgentServer;

/**
 * Handle an embedded JORAM server.
 * @author Loris Bouzonnet
 */
public final class JORAMServer {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(JORAMServer.class);

    private final short id;

    private final String hostname;

    private final int port;

    private final String topicConnectionFactoryName;

    private final String queueConnectionFactoryName;


    public JORAMServer() {
        this((short) 0, "localhost", 16010,
                ContextFactory.DEFAULT_TOPIC_FACTORY_NAME,
                ContextFactory.DEFAULT_QUEUE_FACTORY_NAME);
    }

    public JORAMServer(final short id, final String hostname, final int port,
            final String topicConnectionFactoryName, final String queueConnectionFactoryName) {
        this.id = id;
        this.hostname = hostname;
        this.port = port;
        this.topicConnectionFactoryName = topicConnectionFactoryName;
        this.queueConnectionFactoryName = queueConnectionFactoryName;
    }


    public void start() throws Exception {

        String[] args = {Short.toString(id), "./s" + id};
        fr.dyade.aaa.agent.AgentServer.main(args);

        InputStream is =
            Thread.currentThread().getContextClassLoader().getResourceAsStream("joramAdmin.xml");
        if (is != null) {
            Reader reader = null;
            try {
                reader = new InputStreamReader(is);
                AdminModule.executeAdmin(reader);
            } finally {
                try {
                    if (reader != null) {
                        reader.close();
                    }
                } catch (IOException e) {
                    logger.warn("Unable to close the reader of joramAdmin.xml", e);
                }
            }
        }

        AdminModule.collocatedConnect("root", "root");

        // Creating the JMS administered objects:
        ConnectionFactory topicConnectionFactory =
            TcpConnectionFactory.create(hostname, port);
        ConnectionFactory queueConnectionFactory =
            TcpConnectionFactory.create(hostname, port);
        Context context = new InitialContext();
        context.rebind(topicConnectionFactoryName, topicConnectionFactory);
        context.rebind(queueConnectionFactoryName, queueConnectionFactory);
        context.close();
        // Creating an access for user anonymous:
        User.create("anonymous", "anonymous");
    }

    public void stop() throws Exception {
        Context context = new InitialContext();
        context.unbind(topicConnectionFactoryName);
        context.unbind(queueConnectionFactoryName);
        context.close();
        AgentServer.stop();
    }

    /**
     * @param args
     * @throws Exception
     */
    public static void main(final String[] args) throws Exception {
        JORAMServer server = new JORAMServer();
        server.start();
    }

}
