/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: CPULoadSensor.java 410 2009-01-22 12:43:42Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.sensors;

import java.text.MessageFormat;
import java.text.ParsePosition;
import java.util.HashMap;
import java.util.Map;

/**
 * CPU load sensors. Data are sampled from the /proc/cpu#loadavg file. It
 * exposes 3 fields avg1, avg5, avg15, average load over the 1 respectively 5
 * and 15 seconds.
 */
public final class CPULoadSensor extends TextFileSensor implements Sensor {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 7148272476654277269L;

    /**
     * Default Constructor
     */
    public CPULoadSensor() {
        super("/proc/loadavg");
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.wildcat.sensors.TextFileSensor#getValues(java.lang.String[])
     */
    @Override
    protected Map<String, Object> getValues(final String[] lines) {
        Map<String, Object> samples = new HashMap<String, Object>();
        Object[] loads = FORMAT.parse(lines[0], new ParsePosition(0));
        samples.put("avg1", new Double((String) loads[0]));
        samples.put("avg5", new Double((String) loads[1]));
        samples.put("avg15", new Double((String) loads[2]));
        return samples;
    }

    private static MessageFormat FORMAT = new MessageFormat("{0} {1} {2} {3}");
}
