/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: JavaRuntimeSensor.java 410 2009-01-22 12:43:42Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.sensors;

import java.util.HashMap;
import java.util.Map;

import org.ow2.wildcat.hierarchy.attribute.POJOAttribute;

/**
 * JavaRuntimeSensor, exposes JVM Runtime info.
 */
public final class JavaRuntimeSensor extends POJOAttribute implements Sensor {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -718988846598194215L;

    /**
     * Default constructor
     */
    public JavaRuntimeSensor() {
        super(null);
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.wildcat.hierarchy.attribute.POJOAttribute#getValue()
     */
    @Override
    public Object getValue() {
        Map<String, Object> samples = new HashMap<String, Object>();
        Runtime rt = Runtime.getRuntime();
        samples.put("processors-count", rt.availableProcessors());
        samples.put("free-memory", rt.freeMemory());
        samples.put("maximum-memory", rt.maxMemory());
        samples.put("total-memory", rt.totalMemory());
        return samples;
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.wildcat.hierarchy.attribute.POJOAttribute#setValue(java.lang.Object)
     */
    @Override
    public Object setValue(final Object value) {
        return super.setValue(this.value);
    }
}
