/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2009 Bull S.A.S.
 * Copyright (C) 2009 EMN
 * Copyright (C) 2009 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: QueryTest.java 540 2010-07-13 10:58:13Z mahmoudbh $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.test;

import com.espertech.esper.client.UpdateListener;
import com.espertech.esper.client.EventBean;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.Query;
import org.testng.Assert;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/**
 * Queries related operations unit tests.
 * 
 * @author Mahmoud Ben Hassine
 */
public class QueryTest {

	private Context ctx;
	private Query q;
	
    private int i = 0, j = 0, k = 0, l = 0;

	@BeforeMethod
	protected void setUp() throws Exception {
    	ctx = ContextFactory.getDefaultFactory().createContext();
    	q = ctx.createQuery("select * from WHierarchyEvent");
    }
    
    @Test
    public void testRemoveListeners() throws ContextException {

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                    i++;
            }

        };

        ctx.registerListeners(q, ul);

        ctx.createResource("self://r1");
        Assert.assertEquals(1, i);

        ctx.removeListeners(q, ul);

        ctx.createResource("self://r2");

        Assert.assertEquals(1, i);

    }

    @Test
    public void testDestroyQuery() throws ContextException {

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                    j++;
            }

        };

        ctx.registerListeners(q, ul);

        ctx.createResource("self://r1");
        Assert.assertEquals(1, j);

        ctx.destroyQuery(q);

        ctx.createResource("self://r2");
        Assert.assertEquals(1, j);

    }

    @Test
    public void testPauseQuery() throws ContextException {

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                    k++;
            }

        };

        ctx.registerListeners(q, ul);

        ctx.createResource("self://r1");
        Assert.assertEquals(1, k);

        ctx.pauseQuery(q);

        ctx.createResource("self://r2");
        Assert.assertEquals(1, k);
        
    }
    
    @Test
    public void testResumeQuery() throws ContextException {

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                    l++;
            }

        };

        ctx.registerListeners(q, ul);

        ctx.createResource("self://r1");
        Assert.assertEquals(1, l);

        ctx.pauseQuery(q);

        ctx.createResource("self://r2");
        Assert.assertEquals(1, l);

        ctx.resumeQuery(q);

        ctx.createResource("self://r3");
        Assert.assertEquals(2, l);

    }
    
	@AfterMethod
	protected void tearDown() throws Exception {
		ctx = null;
		q = null;
		System.gc();
	}

}
