/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: TestPull.java 539 2010-07-13 09:42:46Z mahmoudbh $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.test;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.testng.Assert;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/**
 * Unit test for pull mode operations on {@link org.ow2.wildcat.Context}.
 */
public class TestPull {

    private Context context = null;

    /**
     * Initialize a context
     * @return 
     * @throws ContextException
     */
    @BeforeMethod
    public void setup() throws ContextException {
        this.context = ContextFactory.getDefaultFactory().createContext();
        this.context.createAttribute("self://test#attribute", 17);
        this.context.createAttribute("self://test#hello", "Hello");
        this.context.createSymlink("self://symlink", "self://test");
    }

    /**
     * Test method for
     * {@link org.ow2.wildcat.Context#getValue(java.lang.String)}.
     * @throws ContextException
     */
    @Test
    public void testGetValue() throws ContextException {
        Object attr = this.context.getValue("self://test#attribute");
        Assert.assertTrue(attr instanceof Integer);
        Assert.assertTrue(17 == (Integer) attr);
    }

    /**
     * Test method for
     * {@link org.ow2.wildcat.Context#getValue(java.lang.String)}.
     * @throws ContextException
     */
    @Test
    public void testGetValueThroughSymlink() throws ContextException {
        Object attr = this.context.getValue("self://symlink#attribute");
        Assert.assertTrue(attr instanceof Integer);
        Assert.assertTrue(17 == (Integer) attr);
    }

    /**
     * Test method for
     * {@link org.ow2.wildcat.Context#setValue(java.lang.String)}.
     * @throws ContextException
     */
    @Test
    public void testSetValue() throws ContextException {
        Object oo = this.context.setValue("self://test#hello",
        "Hello World !!!");
        Assert.assertTrue(oo instanceof String);
        Assert.assertTrue("Hello".equals(oo));

        Object nn = this.context.getValue("self://test#hello");
        Assert.assertTrue(nn instanceof String);
        Assert.assertTrue("Hello World !!!".equals(nn));
    }

    /**
     * Test method for {@link org.ow2.wildcat.Context#list(java.lang.String)}.
     * @throws ContextException
     */
    @Test
    public void testList() throws ContextException {
        Assert.assertTrue(this.context.list("self://test").size() == 2);
    }
}
